@@ -1,36 +1,34 @@
 """Module providing various functions for processing more complex structured data (e.g., collected during a study)."""
 import warnings
-from typing import Sequence, Union, Dict, Optional, Tuple, Any
-
-# from tqdm.auto import tqdm
+from typing import Any, Dict, Optional, Sequence, Tuple, Union
 
 import numpy as np
 import pandas as pd
 from scipy import interpolate
 
 from biopsykit.utils._datatype_validation_helper import (
-    _assert_is_dtype,
     _assert_dataframes_same_length,
     _assert_has_index_levels,
     _assert_has_multiindex,
+    _assert_is_dtype,
 )
-from biopsykit.utils.functions import se
 from biopsykit.utils.array_handling import sanitize_input_1d
 from biopsykit.utils.datatype_helper import (
-    SubjectConditionDict,
-    SubjectConditionDataFrame,
-    is_subject_condition_dataframe,
-    is_subject_condition_dict,
-    SubjectDataDict,
-    StudyDataDict,
-    MergedStudyDataDict,
-    is_merged_study_data_dict,
-    is_subject_data_dict,
-    is_study_data_dict,
     MeanSeDataFrame,
+    MergedStudyDataDict,
+    StudyDataDict,
+    SubjectConditionDataFrame,
+    SubjectConditionDict,
+    SubjectDataDict,
     _MeanSeDataFrame,
     is_mean_se_dataframe,
+    is_merged_study_data_dict,
+    is_study_data_dict,
+    is_subject_condition_dataframe,
+    is_subject_condition_dict,
+    is_subject_data_dict,
 )
+from biopsykit.utils.functions import se
 
 
 def _split_data_series(data: pd.DataFrame, time_intervals: pd.Series, include_start: bool) -> Dict[str, pd.DataFrame]:
@@ -513,7 +511,7 @@ def get_subphase_durations(
       i.e., each subphase begins right after the previous one, and the entries indicate the *durations* of each
       subphase. The start and end times of each subphase will then be computed from the subphase durations.
     * If the dictionary entries in ``subphases`` are tuples, it's assumed that the start and end times of each
-    subphase are directly provided.
+      subphase are directly provided.
 
     .. note::
         If the duration of the last subphase is unknown (e.g., because it has variable length) this can be
